@@ -19,7 +19,7 @@ You should have received a copy of the GNU Lesser General Public License along
 with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__version__ = "0.4.4"
+__version__ = "0.4.5"
 
 from libxml2dom.macrolib import *
 from libxml2dom.macrolib import \
@@ -31,6 +31,16 @@ from libxml2dom.macrolib import \
 import urllib # for parseURI in HTML mode
 import xml.dom # for getElementById
 
+# Standard namespaces.
+
+XML_NAMESPACE = xml.dom.XML_NAMESPACE
+
+# Default namespace bindings for XPath.
+
+default_ns = {
+    "xml" : XML_NAMESPACE
+    }
+
 class Implementation(object):
 
     "Contains an abstraction over the DOM implementation."
@@ -478,7 +488,10 @@ class Node(object):
     # NOTE: To be finished.
 
     def xpath(self, expr, variables=None, namespaces=None):
-        result = Node_xpath(self._node, expr, variables, namespaces)
+        ns = {}
+        ns.update(default_ns)
+        ns.update(namespaces or {})
+        result = Node_xpath(self._node, expr, variables, ns)
         if isinstance(result, str):
             return to_unicode(result)
         elif hasattr(result, "__len__"):
