@@ -85,6 +85,11 @@ def _find_namespace(node, ns, prefix):
     and 'prefix'.
     """
 
+    # Special treatment for XML namespace.
+
+    if prefix == "xml" and ns == xml.dom.XML_NAMESPACE:
+        return libxml2mod.xmlSearchNsByHref(Node_ownerDocument(node), node, xml.dom.XML_NAMESPACE)
+
     new_ns = None
     current = libxml2mod.xmlNodeGetNsDefs(node)
     while current is not None:
@@ -253,19 +258,19 @@ def Node_localName(node):
     return to_unicode(libxml2mod.name(node))
 
 def Node_parentNode(node):
-    if libxml2mod.type(node) == "document_xml":
+    if node is None or libxml2mod.type(node) == "document_xml":
         return None
     else:
         return libxml2mod.parent(node)
 
 def Node_previousSibling(node):
-    if libxml2mod.prev(node) is not None:
+    if node is not None and libxml2mod.prev(node) is not None:
         return libxml2mod.prev(node)
     else:
         return None
 
 def Node_nextSibling(node):
-    if libxml2mod.next(node) is not None:
+    if node is not None and libxml2mod.next(node) is not None:
         return libxml2mod.next(node)
     else:
         return None
@@ -323,6 +328,9 @@ def Node_setAttributeNS(node, ns, name, value):
             if prefix is None:
                 prefix = _get_invented_prefix(node, ns)
             new_ns = _make_namespace(node, ns, prefix, set_default=0)
+        # Remove any conflicting attribute.
+        if Node_hasAttributeNS(node, ns, localName):
+            Node_removeAttributeNS(node, ns, localName)
         libxml2mod.xmlSetNsProp(node, new_ns, localName, value)
     else:
         # NOTE: Needs verifying: what should happen to the namespace?
@@ -504,6 +512,18 @@ class LSException(Exception):
     PARSE_ERR = 81
     SERIALIZE_ERR = 82
 
+    def __repr__(self):
+        return str(self)
+
+    def __str__(self):
+        exctype = self.args[0]
+        if exctype == self.PARSE_ERR:
+            return "Parse error: LSException(%d)" % exctype
+        elif exctype == self.SERIALIZE_ERR:
+            return "Serialize error: LSException(%d)" % exctype
+        else:
+            return Exception.__repr__(self)
+
 # Utility functions.
 
 def createDocument(namespaceURI, localName, doctype):
@@ -528,6 +548,8 @@ def parseFile(s, html=0, htmlencoding=None, unfinished=0):
     # NOTE: Switching off validation and remote DTD resolution.
     if not html:
         context = libxml2mod.xmlCreateFileParserCtxt(s)
+        if context is None:
+            raise LSException(LSException.PARSE_ERR)
         Parser_configure(context)
         Parser_parse(context)
         doc = Parser_document(context)
@@ -542,6 +564,8 @@ def parseString(s, html=0, htmlencoding=None, unfinished=0):
     # NOTE: Switching off validation and remote DTD resolution.
     if not html:
         context = libxml2mod.xmlCreateMemoryParserCtxt(s, len(s))
+        if context is None:
+            raise LSException(LSException.PARSE_ERR)
         Parser_configure(context)
         Parser_parse(context)
         doc = Parser_document(context)
@@ -559,6 +583,8 @@ def parseURI(uri, html=0, htmlencoding=None, unfinished=0):
     # NOTE: Switching off validation and remote DTD resolution.
     if not html:
         context = libxml2mod.xmlCreateURLParserCtxt(uri, 0)
+        if context is None:
+            raise LSException(LSException.PARSE_ERR)
         Parser_configure(context)
         Parser_parse(context)
         doc = Parser_document(context)
