@@ -54,6 +54,8 @@ import socket
 import select
 import base64 # for auth elements
 
+# XMPP-related namespaces.
+
 XMPP_BIND_NAMESPACE = "urn:ietf:params:xml:ns:xmpp-bind"
 XMPP_CLIENT_NAMESPACE = "jabber:client"
 XEP_0022_EVENT_NAMESPACE = "jabber:x:event"
@@ -62,6 +64,18 @@ XMPP_SASL_NAMESPACE = "urn:ietf:params:xml:ns:xmpp-sasl"
 XMPP_SESSION_NAMESPACE = "urn:ietf:params:xml:ns:xmpp-session"
 XMPP_STREAMS_NAMESPACE = "http://etherx.jabber.org/streams"
 
+# Default namespace bindings for XPath.
+
+default_ns = {
+    "bind" : XMPP_BIND_NAMESPACE,
+    "client" : XMPP_CLIENT_NAMESPACE,
+    "event": XEP_0022_EVENT_NAMESPACE,
+    "register" : XMPP_REGISTER_NAMESPACE,
+    "sasl" : XMPP_SASL_NAMESPACE,
+    "session" : XMPP_SESSION_NAMESPACE,
+    "stream" : XMPP_STREAMS_NAMESPACE
+    }
+
 class XMPPImplementation(libxml2dom.Implementation):
 
     "Contains an XMPP-specific implementation."
@@ -141,25 +155,18 @@ class XMPPImplementation(libxml2dom.Implementation):
 
 class XMPPNode(libxml2dom.Node):
 
-    "Convenience modifications to nodes specific to libxml2dom.svg."
+    "Convenience modifications to nodes specific to libxml2dom.xmpp."
 
     def xpath(self, expr, variables=None, namespaces=None):
 
         """
         Evaluate the given 'expr' using the optional 'variables' and
-        'namespaces'. If not otherwise specified, the "stream" prefix will be
-        bound to XMPP_STREAMS_NAMESPACE as defined in this module.
+        'namespaces'. If not otherwise specified, the prefixes given in the
+        module global 'default_ns' will be bound as in that dictionary.
         """
 
-        ns = {
-            "bind" : XMPP_BIND_NAMESPACE,
-            "client" : XMPP_CLIENT_NAMESPACE,
-            "event": XEP_0022_EVENT_NAMESPACE,
-            "register" : XMPP_REGISTER_NAMESPACE,
-            "sasl" : XMPP_SASL_NAMESPACE,
-            "session" : XMPP_SESSION_NAMESPACE,
-            "stream" : XMPP_STREAMS_NAMESPACE
-            }
+        ns = {}
+        ns.update(default_ns)
         ns.update(namespaces or {})
         return libxml2dom.Node.xpath(self, expr, variables, ns)
 
@@ -169,6 +176,9 @@ class XMPPDocument(libxml2dom._Document, XMPPNode):
 
     pass
 
+class XMPPElement(XMPPNode):
+    pass
+
 class XMPPAuthElement(XMPPNode):
 
     "An XMPP auth element."
@@ -383,9 +393,6 @@ class XMPPRegisterElement(XMPPNode):
 class XMPPStreamElement(XMPPNode):
     pass
 
-class XMPPElement(XMPPNode):
-    pass
-
 # Classes providing XMPP session support.
 
 class SessionTerminated(Exception):
